"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const compiler_1 = require("../services/compiler");
const file_1 = require("../services/file");
const checkFolder_1 = require("../helpers/checkFolder");
const log_1 = require("../helpers/log");
const service_worker_1 = require("../services/service_worker");
class Build extends command_1.Command {
    async run() {
        const { flags: { dev } } = this.parse(Build);
        const config = await file_1.getConfig();
        await log_1.logBuildMode(dev);
        if (!await checkFolder_1.doFoldersExist()) {
            return false;
        }
        cli_ux_1.default.action.start('Building files');
        console.time('Build time');
        const htmlPages = await compiler_1.build(dev, config);
        await file_1.saveHTMLToFiles(htmlPages);
        await Promise.all([
            file_1.copyStaticFolder(config.staticFolder),
            file_1.copyExtraStaticFiles(config.extraStaticFiles),
            service_worker_1.generateSW(config.sw, dev),
        ]);
        cli_ux_1.default.action.stop();
        console.timeEnd('Build time');
    }
}
Build.description = 'Starts building templates for production';
Build.flags = {
    dev: command_1.flags.boolean({
        default: false,
        description: 'Enable development mode for your builds',
    }),
};
exports.Build = Build;
