"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const js_beautify_1 = tslib_1.__importDefault(require("js-beautify"));
const path_1 = require("path");
const file_1 = require("../file");
const glob_1 = tslib_1.__importDefault(require("../../helpers/glob"));
const CWD = process.cwd();
const SW_DEFAULT_TEMPLATE = 'sw.js';
exports.generateSW = async (sw = SW_DEFAULT_TEMPLATE, dev) => {
    const [pages, swFile] = await Promise.all([
        glob_1.default('pages/**/*.js'),
        file_1.getServiceWorker(sw),
    ]);
    const paths = pages.map((page) => {
        const path = page.replace('pages', '').replace('.js', '.html').split('/');
        const filename = path.pop();
        const route = path.join('/') || '/';
        return {
            route,
            filename,
            index: filename === 'index.html',
            depth: path.length - 1,
        };
    }).sort((a, b) => a.depth - b.depth);
    const serviceWorker = `
    const DEV = ${JSON.stringify(dev)};
    const routes = ${JSON.stringify(paths, null, 3)}

    ${swFile}
  `;
    const cleanUpFile = js_beautify_1.default(serviceWorker, { indent_size: 2, keep_array_indentation: true });
    return fs_extra_1.default.outputFile(path_1.normalize(`${CWD}/dist/${sw}`), cleanUpFile);
};
